## 안녕하세요(annyeonghaseyo), I'm Jinsung Ha!
From your terminal,
```bash
pip install jinsung
```
Then,

```python
import jinsung
```

## Github Stats

---
[![Jinsung Ha's Github Stats](https://github-readme-stats.vercel.app/api?username=jha929&count_private=true&show_icons=true)](https://github.com/jha929)
[![Jinsung Ha's Top Languages](https://github-readme-stats.vercel.app/api/top-langs/?username=jha929&hide=jupyter%20notebook&hide_border=true&layout=compact)](https://github.com/jha929)
